# Gowin Boards

The {py:mod}`torii_boards.gowin` module provides a collection of Gowin FPGA development boards, they are based off the Torii {py:class}`GowinPlatform <torii.platform.vendor.gowin.GowinPlatform>` platform and support [Gowin] devices with the [Apicula] and the vendor toolchains.

```{toctree}
:maxdepth: 2
gw1n
```

[Apicula]: https://github.com/YosysHQ/apicula
[Gowin]: https://www.gowinsemi.com/en/support/home/
